@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """Tests for `fnmatch`."""
 import unittest
+import re
 import pytest
 import wcmatch.fnmatch as fnmatch
 from unittest import mock
@@ -150,6 +151,13 @@ class TestFnMatch:
         ['[[:alnum:]]bc', '1bc', True, 0],
         ['[a[:alnum:]]bc', 'zbc', True, 0],
         ['[[:alnum:][:blank:]]bc', ' bc', True, 0],
+        ['*([[:word:]])', 'WoRD5_', True, fnmatch.E],
+
+        [b'[[:alnum:]]bc', b'zbc', True, 0],
+        [b'[[:alnum:]]bc', b'1bc', True, 0],
+        [b'[a[:alnum:]]bc', b'zbc', True, 0],
+        [b'[[:alnum:][:blank:]]bc', b' bc', True, 0],
+        [b'*([[:word:]])', b'WoRD5_', True, fnmatch.E],
 
         # POSIX character classes are case sensitive
         ['[[:ALNUM:]]bc', 'zbc', False, 0],
@@ -326,6 +334,30 @@ class TestFnMatchTranslate(unittest.TestCase):
 
         return fnmatch.translate(pattern, flags=flags | fnmatch.SPLIT)
 
+    def test_capture_groups(self):
+        """Test capture groups."""
+
+        gpat = fnmatch.translate("test @(this) +(many) ?(meh)*(!) !(not this)@(.md)", flags=fnmatch.E)
+        pat = re.compile(gpat[0][0])
+        match = pat.match('test this manymanymany meh!!!!! okay.md')
+        self.assertEqual(('this', 'manymanymany', 'meh', '!!!!!', 'okay', '.md'), match.groups())
+
+    def test_nested_capture_groups(self):
+        """Test nested capture groups."""
+
+        gpat = fnmatch.translate("@(file)@(+([[:digit:]]))@(.*)", flags=fnmatch.E)
+        pat = re.compile(gpat[0][0])
+        match = pat.match('file33.test.txt')
+        self.assertEqual(('file', '33', '33', '.test.txt'), match.groups())
+
+    def test_list_groups(self):
+        """Test capture groups with lists."""
+
+        gpat = fnmatch.translate("+(f|i|l|e)+([[:digit:]])@(.*)", flags=fnmatch.E)
+        pat = re.compile(gpat[0][0])
+        match = pat.match('file33.test.txt')
+        self.assertEqual(('file', '33', '.test.txt'), match.groups())
+
     def test_split_parsing(self):
         """Test wildcard parsing."""
 
@@ -334,88 +366,50 @@ class TestFnMatchTranslate(unittest.TestCase):
         flags = self.flags | fnmatch.FORCEUNIX
 
         p1, p2 = self.split_translate('*test[a-z]?|*test2[a-z]?|!test[!a-z]|!test[!-|a-z]', flags | fnmatch.N)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:(?=.).*?test[a-z].)$', r'^(?s:(?=.).*?test2[a-z].)$'])
-            self.assertEqual(p2, [r'^(?s:test[^a-z])$', r'^(?s:test[^\-\|a-z])$'])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:(?=.).*?test[a-z].)$', r'(?s)^(?:(?=.).*?test2[a-z].)$'])
-            self.assertEqual(p2, [r'(?s)^(?:test[^a-z])$', r'(?s)^(?:test[^\-\|a-z])$'])
+        self.assertEqual(p1, [r'^(?s:(?=.).*?test[a-z].)$', r'^(?s:(?=.).*?test2[a-z].)$'])
+        self.assertEqual(p2, [r'^(?s:test[^a-z])$', r'^(?s:test[^\-\|a-z])$'])
 
         p1, p2 = self.split_translate('test[]][!][][]', flags | fnmatch.U | fnmatch.C)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test[\]][^\][]\[\])$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test[\]][^\][]\[\])$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test[\]][^\][]\[\])$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = self.split_translate('test[!]', flags)
         if util.PY37:
             self.assertEqual(p1, [r'^(?s:test\[!\])$'])
             self.assertEqual(p2, [])
-        elif util.PY36:
-            self.assertEqual(p1, [r'^(?s:test\[\!\])$'])
-            self.assertEqual(p2, [])
         else:
-            self.assertEqual(p1, [r'(?s)^(?:test\[\!\])$'])
+            self.assertEqual(p1, [r'^(?s:test\[\!\])$'])
             self.assertEqual(p2, [])
 
         p1, p2 = self.split_translate('|test|', flags)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:)$', r'^(?s:test)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:)$', r'(?s)^(?:test)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:)$', r'^(?s:test)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = self.split_translate('-|-test|-', flags=flags | fnmatch.N | fnmatch.M)
-        if util.PY36:
-            self.assertEqual(p1, [])
-            self.assertEqual(p2, [r'^(?s:)$', r'^(?s:test)$'])
-        else:
-            self.assertEqual(p1, [])
-            self.assertEqual(p2, [r'(?s)^(?:)$', r'(?s)^(?:test)$'])
+        self.assertEqual(p1, [])
+        self.assertEqual(p2, [r'^(?s:)$', r'^(?s:test)$'])
 
         p1, p2 = self.split_translate('test[^chars]', flags)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test[^chars])$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test[^chars])$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test[^chars])$'])
+        self.assertEqual(p2, [])
 
         p1 = self.split_translate(r'test[^\\-\\&]', flags=flags)[0]
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test[^\\-\\\&])$'])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test[^\\-\\\&])$'])
+        self.assertEqual(p1, [r'^(?s:test[^\\-\\\&])$'])
 
         p1 = self.split_translate(r'\\*\\?\\|\\[\\]', flags=flags)[0]
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:\\.*?\\.\\)$', r'^(?s:\\[\\])$'])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:\\.*?\\.\\)$', r'(?s)^(?:\\[\\])$'])
+        self.assertEqual(p1, [r'^(?s:\\.*?\\.\\)$', r'^(?s:\\[\\])$'])
 
         p1 = self.split_translate(r'\\u0300', flags=flags | fnmatch.R)[0]
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:\\u0300)$'])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:\\u0300)$'])
+        self.assertEqual(p1, [r'^(?s:\\u0300)$'])
 
     def test_posix_range(self):
         """Test posix range."""
 
         p = fnmatch.translate(r'[[:ascii:]-z]', flags=self.flags | fnmatch.U | fnmatch.C)
-        if util.PY36:
-            self.assertEqual(p, (['^(?s:[\x00-\x7f\\-z])$'], []))
-        else:
-            self.assertEqual(p, (['(?s)^(?:[\x00-\x7f\\-z])$'], []))
+        self.assertEqual(p, (['^(?s:[\x00-\x7f\\-z])$'], []))
 
         p = fnmatch.translate(r'[a-[:ascii:]-z]', flags=self.flags | fnmatch.U | fnmatch.C)
-        if util.PY36:
-            self.assertEqual(p, (['^(?s:[a\\-\x00-\x7f\\-z])$'], []))
-        else:
-            self.assertEqual(p, (['(?s)^(?:[a\\-\x00-\x7f\\-z])$'], []))
+        self.assertEqual(p, (['^(?s:[a\\-\x00-\x7f\\-z])$'], []))
 
     @mock.patch('wcmatch.util.is_case_sensitive')
     def test_special_escapes(self, mock__iscase_sensitive):
@@ -428,72 +422,41 @@ class TestFnMatchTranslate(unittest.TestCase):
         p1, p2 = fnmatch.translate(
             r'test\x70\u0070\U00000070\160\N{LATIN SMALL LETTER P}', flags=flags | fnmatch.R
         )
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:testppppp)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:testppppp)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:testppppp)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate(
             r'test[\x70][\u0070][\U00000070][\160][\N{LATIN SMALL LETTER P}]', flags=flags | fnmatch.R
         )
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test[p][p][p][p][p])$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test[p][p][p][p][p])$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test[p][p][p][p][p])$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate(r'test\t\m', flags=flags | fnmatch.R)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test\	m)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test\	m)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test\	m)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate(r'test[\\]test', flags=flags | fnmatch.R)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test[\\]test)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test[\\]test)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test[\\]test)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate('test[\\', flags=flags)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test\[\\)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test\[\\)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test\[\\)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate(r'test\44test', flags=flags | fnmatch.R)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test\$test)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test\$test)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test\$test)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate(r'test\44', flags=flags | fnmatch.R)
-        if util.PY36:
-            self.assertEqual(p1, [r'^(?s:test\$)$'])
-            self.assertEqual(p2, [])
-        else:
-            self.assertEqual(p1, [r'(?s)^(?:test\$)$'])
-            self.assertEqual(p2, [])
+        self.assertEqual(p1, [r'^(?s:test\$)$'])
+        self.assertEqual(p2, [])
 
         p1, p2 = fnmatch.translate(r'test\400', flags=flags | fnmatch.R)
         if util.PY37:
             self.assertEqual(p1, [r'^(?s:testĀ)$'])
             self.assertEqual(p2, [])
-        elif util.PY36:
-            self.assertEqual(p1, [r'^(?s:test\Ā)$'])
-            self.assertEqual(p2, [])
         else:
-            self.assertEqual(p1, [r'(?s)^(?:test\Ā)$'])
+            self.assertEqual(p1, [r'^(?s:test\Ā)$'])
             self.assertEqual(p2, [])
 
         with pytest.raises(SyntaxError):
