@@ -1100,6 +1100,30 @@ class TestGlobMatchSpecial(unittest.TestCase):
         self.assertEqual(1, len(pos))
         self.assertEqual(1, len(neg))
 
+    def test_capture_groups(self):
+        """Test capture groups."""
+
+        gpat = glob.translate("test/@(this)/+(many)/?(meh)*(!)/!(not this)@(.md)", flags=glob.E)
+        pat = re.compile(gpat[0][0])
+        match = pat.match(os.path.normpath('test/this/manymanymany/meh!!!!!/okay.md'))
+        self.assertEqual(('this', 'manymanymany', 'meh', '!!!!!', 'okay', '.md'), match.groups())
+
+    def test_nested_capture_groups(self):
+        """Test nested capture groups."""
+
+        gpat = glob.translate("@(file)@(+([[:digit:]]))@(.*)", flags=glob.E)
+        pat = re.compile(gpat[0][0])
+        match = pat.match('file33.test.txt')
+        self.assertEqual(('file', '33', '33', '.test.txt'), match.groups())
+
+    def test_list_groups(self):
+        """Test capture groups with lists."""
+
+        gpat = glob.translate("+(f|i|l|e)+([[:digit:]])@(.*)", flags=glob.E)
+        pat = re.compile(gpat[0][0])
+        match = pat.match('file33.test.txt')
+        self.assertEqual(('file', '33', '.test.txt'), match.groups())
+
     def test_glob_translate(self):
         """Test glob translation."""
 
@@ -1115,19 +1139,10 @@ class TestGlobMatchSpecial(unittest.TestCase):
                 ],
                 []
             )
-        elif util.PY36:
-            value = (
-                [
-                    '^(?s:(?:(?!(?:\\/|^)\\.).)*?(?:^|$|\\/)+' +
-                    ('(?!(?:\\.{1,2})(?:$|\\/))(?![\\/.])[\x00-\x7f]\\/+stuff\\/+(?=[^%s])' % re.escape('/')) +
-                    '(?!(?:\\.{1,2})(?:$|\\/))(?:(?!\\.)[^\\/]*?)?[\\/]*?)$'
-                ],
-                []
-            )
         else:
             value = (
                 [
-                    '(?s)^(?:(?:(?!(?:\\/|^)\\.).)*?(?:^|$|\\/)+' +
+                    '^(?s:(?:(?!(?:\\/|^)\\.).)*?(?:^|$|\\/)+' +
                     ('(?!(?:\\.{1,2})(?:$|\\/))(?![\\/.])[\x00-\x7f]\\/+stuff\\/+(?=[^%s])' % re.escape('/')) +
                     '(?!(?:\\.{1,2})(?:$|\\/))(?:(?!\\.)[^\\/]*?)?[\\/]*?)$'
                 ],
@@ -1501,7 +1516,6 @@ class TestGlobMatchSpecial(unittest.TestCase):
         self.assertFalse(glob.globmatch('markdown', 'markdown', flags=glob.REALPATH))
         self.assertTrue(glob.globmatch('markdown', 'markdown', flags=glob.REALPATH, root_dir='docs/src'))
 
-    @pytest.mark.skipif(not util.PY36, reason="path-like interface not supported on Python < 3.6")
     def test_match_root_dir_pathlib(self):
         """Test root directory with `globmatch` using `pathlib`."""
 
@@ -1512,7 +1526,6 @@ class TestGlobMatchSpecial(unittest.TestCase):
             glob.globmatch(pathlib.Path('markdown'), 'markdown', flags=glob.REALPATH, root_dir=pathlib.Path('docs/src'))
         )
 
-    @pytest.mark.skipif(not util.PY36, reason="path-like interface not supported on Python < 3.6")
     def test_match_root_dir_pathlib_bytes(self):
         """Test root directory with `globmatch` using `pathlib`."""
 
@@ -1527,7 +1540,6 @@ class TestGlobMatchSpecial(unittest.TestCase):
             )
         )
 
-    @pytest.mark.skipif(not util.PY36, reason="path-like interface not supported on Python < 3.6")
     def test_filter_root_dir_pathlib(self):
         """Test root directory with `globfilter`."""
 
@@ -1542,7 +1554,6 @@ class TestGlobMatchSpecial(unittest.TestCase):
 
         self.assertTrue(all([isinstance(result, pathlib.Path) for result in results]))
 
-    @pytest.mark.skipif(not util.PY36, reason="path-like interface not supported on Python < 3.6")
     def test_filter_root_dir_pathlib_bytes(self):
         """Test root directory with `globfilter`."""
 
